@@ -35,7 +35,7 @@ class Profitdataframe(pd.DataFrame):
                                      'ddtype',
                                      '5th_view',])
         for i in col:
-            the5th = ','.join([str(self.loc[i,self.index[j]]) for j in range(5)])
+            the5th = ','.join([str(self[i][self.index[j]]) for j in range(5)])
             value = {'total_count':ind_len,
                      'non_null_count':self[i].count(),
                      'null_count':self[i].isnull().sum(),
